retrofire_core::math

Module angle

Angular quantities, including scalar angles and angular vectors.

Structs

  • A scalar angular quantity.
  • Tag type for a polar coordinate space
  • Tag type for a spherical coordinate space.

Functions

  • Returns an angle of a degrees.
  • Returns a polar coordinate vector with azimuth az and radius r.
  • Returns an angle of a radians.
  • Returns a spherical coordinate vector with azimuth az, altitude alt, and radius r.
  • Returns an angle of a turns.

Type Aliases

  • A polar coordinate vector, with radius and azimuth components.
  • A spherical coordinate vector, with radius, azimuth, and altitude (elevation) components.