retrofire_core::math::angle

Struct Angle

pub struct Angle(/* private fields */);
A scalar angular quantity.

Prevents confusion between degrees and radians by requiring the use of one of the named constructors to create an Angle, as well as one of the named getter methods to obtain the angle as a raw f32 value.

Implementations

Source

impl Angle

pub const ZERO: Self = _

A zero degree angle.

pub const RIGHT: Self = _

A 90 degree angle.

pub const STRAIGHT: Self = _

A 180 degree angle.

pub const FULL: Self = _

A 360 degree angle.

pub const fn to_rads(self) -> f32

Returns the value of self in radians.

Examples
assert_eq!(degs(90.0).to_rads(), f32::consts::FRAC_PI_2);
pub fn to_degs(self) -> f32

Returns the value of self in degrees.

Examples
assert_eq!(turns(2.0).to_degs(), 720.0);
pub fn to_turns(self) -> f32

Returns the value of self in turns.

Examples
assert_eq!(degs(180.0).to_turns(), 0.5);
pub fn min(self, other: Self) -> Self

Returns the minimum of self and other.

pub fn max(self, other: Self) -> Self

Returns the maximum of self and other.

pub fn clamp(self, min: Self, max: Self) -> Self

Returns self clamped to the range min..=max.

Examples
let (min, max) = (degs(0.0), degs(45.0));

assert_eq!(degs(100.0).clamp(min, max), max);

assert_eq!(degs(30.0).clamp(min, max), degs(30.0));

assert_eq!(degs(-10.0).clamp(min, max), min);