retrofire_
core
0.3.2
Module fallback
Module Items
Functions
In retrofire_
core::
math::
float
retrofire_core
::
math
::
float
Module
fallback
Functions

abs
Returns the absolute value of
x
.
floor
Returns the largest integer less than or equal to
x
.
recip_
sqrt
Returns the approximate reciprocal of the square root of
x
.
rem_
euclid