Real and projective vectors.
TODO
Structs
- A generic vector type. Represents an element of a vector space or a module, a generalization of a vector space where the scalars can be integers (technically, the scalar type can be any ring-like type).
Functions
- Returns a vector with all components equal to a scalar.
- Returns a real 2-vector with components
xandy. - Returns a real 3-vector with components
x,y, andz.
Type Aliases
- A
f324-vector in the projective 3-space over ℝ, aka P3(ℝ). - A 2-vector with
f32components. - A 2-vector with
f32components. - A 2-vector with
i32components. - A 2-vector with
u32components. - A 3-vector with
i32components.