retrofire_core::math::vec

Struct Vector

#[repr(transparent)]
pub struct Vector<Repr, Space = ()>(pub Repr, _);
A generic vector type. Represents an element of a vector space or a module, a generalization of a vector space where the scalars can be integers (technically, the scalar type can be any ring-like type).

Type parameters

  • Repr: Representation of the scalar components of the vector, for example an array or a SIMD vector.
  • Space: The space that the vector is an element of. A tag type used to prevent mixing up vectors of different spaces and bases.

Examples

TODO

Tuple Fields

0: Repr

Implementations

Source

impl Vector<[f32; 2], Polar>

pub fn r(&self) -> f32

Returns the radial component of self.

pub fn az(&self) -> Angle

Returns the azimuthal component of self.

Source

impl Vector<[f32; 3], Spherical>

pub fn r(&self) -> f32

Returns the radial component of self.

pub fn az(&self) -> Angle

Returns the azimuthal component of self.

pub fn alt(&self) -> Angle

Returns the altitude (elevation) component of self.

Source

impl<R, Sp> Vector<R, Sp>

pub const fn new(repr: R) -> Self

Returns a new vector with representation repr.

pub fn to<S>(self) -> Vector<R, S>

Returns a vector with value equal to self but in space S.

This method can be used to coerce a vector from one space to another in order to make types match. One use case is to cast a “generic” vector returned by one of the constructor functions to a more specific space.

Source

impl<Sp, const N: usize> Vector<[f32; N], Sp>

pub fn normalize(&self) -> Self

Returns self normalized to unit length.

Examples
let normalized: Vec2 = vec2(3.0, 4.0).normalize();
assert_approx_eq!(normalized, vec2(0.6, 0.8), eps=1e-2);
assert_approx_eq!(normalized.len_sqr(), 1.0, eps=1e-2);
Panics

Panics in dev mode if self is a zero vector.

pub fn clamp(&self, min: &Self, max: &Self) -> Self

Returns self clamped component-wise to the given range.

In other words, for each component self[i], the result r has r[i] equal to self[i].clamp(min[i], max[i]).

Examples
let v: Vec3 = vec3(0.5, 1.5, -2.0);
// Clamp to the unit cube
let v = v.clamp(&splat(-1.0), &splat(1.0));
assert_eq!(v, vec3(0.5, 1.0, -1.0));
Source

impl<Sc, Sp, const N: usize> Vector<[Sc; N], Sp>
where Self: Linear<Scalar = Sc>, Sc: Linear<Scalar = Sc> + Copy,

pub fn len_sqr(&self) -> Sc

Returns the length of self, squared.

This avoids taking the square root in cases it’s not needed and works with scalars for which a square root is not defined.

pub fn dot(&self, other: &Self) -> Sc

Returns the dot product of self and other.

pub fn scalar_project(&self, other: &Self) -> Sc
where Sc: Div<Sc, Output = Sc>,

Returns the scalar projection of self onto other (the length of the component of self parallel to other).

pub fn vector_project(&self, other: &Self) -> Self
where Sc: Div<Sc, Output = Sc>,

Returns the vector projection of self onto other (the vector component of self parallel to other).

           self
           ^
          /.
        /  .
      /    .
    /      .
  /       _.
 +-------'->-----> other
        result
pub fn map<T>(self, f: impl FnMut(Sc) -> T) -> Vector<[T; N], Sp>

Returns a vector of the same dimension as self by applying f component-wise.

Source

impl<R, Sc, B> Vector<R, Real<2, B>>
where R: Index<usize, Output = Sc>, Sc: Copy,

pub fn x(&self) -> Sc

Returns the x component of self.

pub fn y(&self) -> Sc

Returns the y component of self.

Source

impl<R, Sc, B> Vector<R, Real<3, B>>
where R: Index<usize, Output = Sc>, Sc: Copy,

pub fn x(&self) -> Sc

Returns the x component of self.

pub fn y(&self) -> Sc

Returns the y component of self.

pub fn z(&self) -> Sc

Returns the z component of self.

pub fn cross(&self, other: &Self) -> Self
where Sc: Linear<Scalar = Sc>, [Sc; 3]: Into<Self>,

Returns the cross product of self with other.

The result is a vector perpendicular to both input vectors, its length proportional to the area of the parallelogram formed by the vectors. Specifically, the length is given by the identity:

    |𝗮 × 𝗯| = |𝗮| |𝗯| sin 𝜽

where |·| denotes the length of a vector and 𝜽 equals the angle between 𝗮 and 𝗯.

       ^
    r  |
    e  |
    s  |    other
    u  |     ^ - - - - - +
    l  |   /           /
    t  | /           /
       +-----------> self
Source

impl<R, Sc> Vector<R, Proj4>
where R: Index<usize, Output = Sc>, Sc: Copy,

pub fn x(&self) -> Sc

Returns the x component of self.

pub fn y(&self) -> Sc

Returns the y component of self.

pub fn z(&self) -> Sc

Returns the z component of self.

pub fn w(&self) -> Sc

Returns the w component of self.

Source

impl Vector<[f32; 2], Real<2, Tex>>

pub const fn u(&self) -> f32

Returns the u (horizontal) component of self.

pub const fn v(&self) -> f32

Returns the v (vertical) component of self.