retrofire_core

Module render

Turning 3D geometry into raster images.

This module constitutes the core 3D rendering pipeline of retrofire. It contains code for clipping, transforming, shading, texturing, rasterizing, and outputting basic geometric shapes such as triangles.

Modules

  • Builder for setting up geometry for rendering.
  • Cameras and camera transforms.
  • Clipping geometric shapes against planes.
  • Rendering context and parameters.
  • Translation of vector shapes into discrete pixels in the framebuffer.
  • Fragment and vertex shaders.
  • Rendering statistics.
  • Render targets such as framebuffers.
  • Textures and texture samplers.

Structs

  • Model space coordinate basis.
  • NDC space coordinate basis (normalized device coordinates).
  • Screen space coordinate basis.
  • View (camera) space coordinate basis.
  • World space coordinate basis.

Traits

  • Alias for combined vertex+fragment shader types

Functions

  • Renders the given triangles into target.

Type Aliases