retrofire_core::render::batch

Struct Batch

pub struct Batch<Vtx, Uni, Shd, Tgt, Ctx> { /* private fields */ }
A builder for rendering a chunk of geometry as a batch.

Several values must be assigned before the render method can be called:

  • faces: A list of triangles, each a triplet of indices into the list of vertices (TODO: handling oob)
  • vertices: A list of vertices
  • shader: The combined vertex and fragment shader used
  • target: The render target to render into
  • context: The rendering context and settings used. (TODO: optional?)

Additionally, setting the following values is optional:

  • uniform: The uniform value passed to the vertex shader
  • viewport: The matrix used for the NDC-to-screen transform.

Implementations

Source

impl Batch<(), (), (), (), Context>

pub fn new() -> Self

Source

impl<Vtx, Uni, Shd, Tgt, Ctx> Batch<Vtx, Uni, Shd, Tgt, Ctx>

pub fn faces(self, faces: impl AsRef<[Tri<usize>]>) -> Self

Sets the faces to be rendered.

The faces are copied into the batch.

pub fn vertices<V: Clone>( self, verts: impl AsRef<[V]>, ) -> Batch<V, Uni, Shd, Tgt, Ctx>

Sets the vertices to be rendered.

The vertices are cloned into the batch.

pub fn mesh<A: Clone>( self, mesh: &Mesh<A>, ) -> Batch<Vertex<A>, Uni, Shd, Tgt, Ctx>

Clones faces and vertices from a mesh to this batch.

pub fn uniform<U: Copy>(self, uniform: U) -> Batch<Vtx, U, Shd, Tgt, Ctx>

Sets the uniform data to be passed to the vertex shaders.

pub fn shader<V: Vary, S: Shader<Vtx, V, Uni>>( self, shader: S, ) -> Batch<Vtx, Uni, S, Tgt, Ctx>

Sets the combined vertex and fragment shader.

pub fn viewport(self, viewport: Mat4x4<NdcToScreen>) -> Self

Sets the viewport matrix.

pub fn target<T>(self, target: T) -> Batch<Vtx, Uni, Shd, T, Ctx>

Sets the render target.

pub fn context(self, ctx: &Context) -> Batch<Vtx, Uni, Shd, Tgt, &Context>

Sets the rendering context.

Source

impl<Vtx: Clone, Uni: Copy, Shd, Tgt: Target, Ctx> Batch<Vtx, Uni, Shd, &mut Tgt, Ctx>
where Ctx: Borrow<Context>,

pub fn render<V: Vary>(&mut self)
where Shd: Shader<Vtx, V, Uni>,

Renders this batch of geometry.