retrofire_core::util::buf::inner

Struct Inner

pub struct Inner<T, D> { /* private fields */ }
A helper type that abstracts over owned and borrowed buffers.

The types Buf2, Slice2, and MutSlice2 deref to Inner.

Implementations

Source

impl<T, D> Inner<T, D>

pub fn width(&self) -> u32

Returns the width of self.

pub fn height(&self) -> u32

Returns the height of self.

pub fn stride(&self) -> u32

Returns the stride of self.

pub fn is_contiguous(&self) -> bool

Returns whether the rows of self are stored as one contiguous slice, without gaps between rows.

Buf2 instances are always contiguous. A Slice2 or MutSlice2 instance is contiguous if its width equals its stride, if its height is 1, or if it is empty.

pub fn is_empty(&self) -> bool

Returns whether self contains no elements.

Source

impl<T, D: Deref<Target = [T]>> Inner<T, D>

pub fn as_slice2(&self) -> Slice2<'_, T>

Borrows self as a Slice2.

pub fn slice(&self, rect: impl Into<Rect>) -> Slice2<'_, T>

Returns a borrowed rectangular slice of self.

Panics

If any part of rect is outside the bounds of self.

pub fn get(&self, pos: impl Into<Vec2u>) -> Option<&T>

Returns a reference to the element at pos, or None if pos is out of bounds.

pub fn rows(&self) -> impl Iterator<Item = &[T]>

Returns an iterator over the rows of self as &[T] slices.

The length of each slice equals self.width().

pub fn iter(&self) -> impl Iterator<Item = &T>

Returns an iterator over all the elements of self in row-major order.

First returns the elements on row 0 from left to right, followed by the elements on row 1, and so on.

Source

impl<T, D: DerefMut<Target = [T]>> Inner<T, D>

pub fn as_mut_slice2(&mut self) -> MutSlice2<'_, T>

Returns a mutably borrowed rectangular slice of self.

pub fn rows_mut(&mut self) -> impl Iterator<Item = &mut [T]>

Returns an iterator over the rows of this buffer as &mut [T].

The length of each slice equals self.width().

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

Returns an iterator over all the elements of self in row-major order: first the elements on row 0 from left to right, followed by the elements on row 1, and so on.

pub fn fill(&mut self, val: T)
where T: Clone,

Fills self with clones of val.

pub fn fill_with<F>(&mut self, fill_fn: F)
where F: Copy + FnMut(u32, u32) -> T,

Fills self by invoking f(x, y) for every element, where x and y are the column and row of the element, respectively.

pub fn copy_from(&mut self, src: impl AsSlice2<T>)
where T: Copy,

Copies each element in src to the same position in self.

This operation is often called “blitting”.

Panics

if the dimensions of self and src don’t match.

pub fn get_mut(&mut self, pos: impl Into<Vec2u>) -> Option<&mut T>

Returns a mutable reference to the element at pos, or None if pos is out of bounds.

pub fn slice_mut(&mut self, rect: impl Into<Rect>) -> MutSlice2<'_, T>

Returns a mutably borrowed rectangular slice of self.

Panics

If any part of rect is outside the bounds of self.