retrofire_core::util::buf

Struct Buf2

pub struct Buf2<T>(/* private fields */);
A rectangular 2D buffer that owns its elements, backed by a Vec.

Unlike Vec, however, Buf2 cannot be resized after construction without explicitly copying the contents to a new, larger buffer.

Buf2 stores its elements contiguously, in standard row-major order, such that the coordinate pair (x, y) maps to the index

buf.width() * y + x

in the backing vector.

Examples

// Elements initialized with `Default::default()`
let mut buf = Buf2::new((4, 4));
// Indexing with a 2D vector (x, y) yields element at row y, column x:
buf[vec2(2, 1)] = 123;
// Indexing with an usize i yields row with index i as a slice:
assert_eq!(buf[1usize], [0, 0, 123, 0]);
// Thus you can also do this, row first, column second:
assert_eq!(buf[1usize][2], 123)

Implementations

Source

impl<T> Buf2<T>

pub fn new_from<I>(dims: Dims, init: I) -> Self
where I: IntoIterator<Item = T>,

Returns a buffer with the given dimensions, with elements initialized in row-major order with values yielded by init.

Panics

If there are fewer than w * h elements in init.

pub fn new(dims: Dims) -> Self
where T: Clone + Default,

Returns a buffer with size w × h, with every element initialized by calling T::default().

pub fn new_with<F>(dims: Dims, init_fn: F) -> Self
where F: Clone + FnMut(u32, u32) -> T,

Returns a buffer with size w × h, with every element initialized by calling init_fn(x, y) where x is the column index and y the row index of the element being initialized.

pub fn data(&self) -> &[T]

Returns a view of the backing data of self.

pub fn data_mut(&mut self) -> &mut [T]

Returns a mutable view of the backing data of self.

Methods from Deref<Target = Inner<T, Vec<T>>>

pub fn width(&self) -> u32

Returns the width of self.

pub fn height(&self) -> u32

Returns the height of self.

pub fn stride(&self) -> u32

Returns the stride of self.

pub fn is_contiguous(&self) -> bool

Returns whether the rows of self are stored as one contiguous slice, without gaps between rows.

Buf2 instances are always contiguous. A Slice2 or MutSlice2 instance is contiguous if its width equals its stride, if its height is 1, or if it is empty.

pub fn is_empty(&self) -> bool

Returns whether self contains no elements.

pub fn as_slice2(&self) -> Slice2<'_, T>

Borrows self as a Slice2.

pub fn slice(&self, rect: impl Into<Rect>) -> Slice2<'_, T>

Returns a borrowed rectangular slice of self.

Panics

If any part of rect is outside the bounds of self.

pub fn get(&self, pos: impl Into<Vec2u>) -> Option<&T>

Returns a reference to the element at pos, or None if pos is out of bounds.

pub fn rows(&self) -> impl Iterator<Item = &[T]>

Returns an iterator over the rows of self as &[T] slices.

The length of each slice equals self.width().

pub fn iter(&self) -> impl Iterator<Item = &T>

Returns an iterator over all the elements of self in row-major order.

First returns the elements on row 0 from left to right, followed by the elements on row 1, and so on.

pub fn as_mut_slice2(&mut self) -> MutSlice2<'_, T>

Returns a mutably borrowed rectangular slice of self.

pub fn rows_mut(&mut self) -> impl Iterator<Item = &mut [T]>

Returns an iterator over the rows of this buffer as &mut [T].

The length of each slice equals self.width().

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

Returns an iterator over all the elements of self in row-major order: first the elements on row 0 from left to right, followed by the elements on row 1, and so on.

pub fn fill(&mut self, val: T)
where T: Clone,

Fills self with clones of val.

pub fn fill_with<F>(&mut self, fill_fn: F)
where F: Copy + FnMut(u32, u32) -> T,

Fills self by invoking f(x, y) for every element, where x and y are the column and row of the element, respectively.

pub fn copy_from(&mut self, src: impl AsSlice2<T>)
where T: Copy,

Copies each element in src to the same position in self.

This operation is often called “blitting”.

Panics

if the dimensions of self and src don’t match.

pub fn get_mut(&mut self, pos: impl Into<Vec2u>) -> Option<&mut T>

Returns a mutable reference to the element at pos, or None if pos is out of bounds.

pub fn slice_mut(&mut self, rect: impl Into<Rect>) -> MutSlice2<'_, T>

Returns a mutably borrowed rectangular slice of self.

Panics

If any part of rect is outside the bounds of self.