pub struct Angle(/* private fields */);Expand description
A scalar angular quantity.
Prevents confusion between degrees and radians by requiring the use of
one of the named constructors to create an Angle, as well as one of
the named getter methods to obtain the angle as a raw f32 value.
Implementations