Module fallback

Module fallback 

Functions

abs
Returns the absolute value of x.
floor
Returns the largest integer less than or equal to x.
recip_sqrt
Returns the approximate reciprocal of the square root of x.
rem_euclid