MutSlice2

Struct MutSlice2 

pub struct MutSlice2<'a, T>(/* private fields */);
A mutable rectangular view to a region of a Buf2, a Slice2, or in general any &[T] slice of memory.

Implementations

Source

impl<'a, T> MutSlice2<'a, T>

pub fn new(dims: Dims, stride: u32, data: &'a mut [T]) -> Self

Returns a new MutSlice2 view to data with dimensions w and h and stride stride.

See Slice2::new for more information.